package com.yiqi.order.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.order.domain.OrderClothColor;

/**
 * 洗衣订单衣服颜色Service接口
 *
 * @author ruoyi
 * @date 2023-10-06
 */
public interface IOrderClothColorService extends IService<OrderClothColor> {
    /**
     * 查询洗衣订单衣服颜色
     *
     * @param id 洗衣订单衣服颜色主键
     * @return 洗衣订单衣服颜色
     */
    public OrderClothColor selectOrderClothColorById(Long id);

    /**
     * 查询洗衣订单衣服颜色列表
     *
     * @param orderClothColor 洗衣订单衣服颜色
     * @return 洗衣订单衣服颜色集合
     */
    public List<OrderClothColor> selectOrderClothColorList(OrderClothColor orderClothColor);

    /**
     * 新增洗衣订单衣服颜色
     *
     * @param orderClothColor 洗衣订单衣服颜色
     * @return 结果
     */
    public int insertOrderClothColor(OrderClothColor orderClothColor);

    /**
     * 修改洗衣订单衣服颜色
     *
     * @param orderClothColor 洗衣订单衣服颜色
     * @return 结果
     */
    public int updateOrderClothColor(OrderClothColor orderClothColor);

    /**
     * 批量删除洗衣订单衣服颜色
     *
     * @param ids 需要删除的洗衣订单衣服颜色主键集合
     * @return 结果
     */
    public int deleteOrderClothColorByIds(Long[] ids);

    /**
     * 删除洗衣订单衣服颜色信息
     *
     * @param id 洗衣订单衣服颜色主键
     * @return 结果
     */
    public int deleteOrderClothColorById(Long id);



}
